From b7fe92ce9f35e662059dccd413528087aa99729a Mon Sep 17 00:00:00 2001
From: Lucas Fialho Zawacki <lfzawacki@gmail.com>
Date: Sat, 19 May 2012 20:01:06 -0300
Subject: dinput: Implement GetProperty for JOYSTICKID

This is for Windows the id of the joystick under the winmm driver.
What I'm doing is returning the index of the joystick in the dinput
joystick list.
---
 dlls/dinput/joystick.c |   19 +++++++++++++++++++
 include/dinput.h       |    1 +
 2 files changed, 20 insertions(+)

diff --git a/dlls/dinput/joystick.c b/dlls/dinput/joystick.c
index dfcaeb7..5e30a33 100644
--- a/dlls/dinput/joystick.c
+++ b/dlls/dinput/joystick.c
@@ -290,6 +290,25 @@ HRESULT WINAPI JoystickWGenericImpl_GetProperty(LPDIRECTINPUTDEVICE8W iface, REF
             }
             break;
         }
+        case (DWORD_PTR) DIPROP_JOYSTICKID: {
+            IDirectInputDeviceImpl *dev;
+            LPDIPROPDWORD pd = (LPDIPROPDWORD)pdiph;
+            int i = 0, found = 0;
+
+            /* Find the index of the joystick by looking at all other dinput joysticks */
+            LIST_FOR_EACH_ENTRY( dev, &This->base.dinput->devices_list, IDirectInputDeviceImpl, entry)
+            {
+                if (&This->base == dev) found = i;
+
+                if (!found && !IsEqualGUID(&dev->guid, &GUID_SysKeyboard) && !IsEqualGUID(&dev->guid, &GUID_SysMouse))
+                    i += 1;
+            }
+
+            pd->dwData = found;
+
+            TRACE("joystickid %d\n", pd->dwData);
+            return DI_OK;
+        }
         default:
             return IDirectInputDevice2WImpl_GetProperty(iface, rguid, pdiph);
         }
diff --git a/include/dinput.h b/include/dinput.h
index a6cf7e2..3125800 100644
--- a/include/dinput.h
+++ b/include/dinput.h
@@ -905,6 +905,7 @@ typedef const DIPROPSTRING *LPCDIPROPSTRING;
 
 #define DIPROP_CALIBRATION	MAKEDIPROP(11)
 #define DIPROP_GUIDANDPATH	MAKEDIPROP(12)
+#define DIPROP_JOYSTICKID       MAKEDIPROP(15)
 #define DIPROP_KEYNAME          MAKEDIPROP(20)
 #define DIPROP_VIDPID           MAKEDIPROP(24)
 
-- 
1.7.9.5

